Symbolize a base R lm() fit (Gaussian, v0.10 first slice)
Source:R/symbolize-base.R
symbolize.lm.RdBuilds a symbolized_model from a base R
lm object. v0.10 covers the Gaussian conditional submodel only
(the only family lm() fits). The residual standard deviation
(summary(fit)$sigma) is exposed as the sigma variance component
but is not modelled – lm() doesn't support distributional
regression on sigma.
Usage
# S3 method for class 'lm'
symbolize(fit, symbols = NULL, units = NULL, context = NULL, ...)Arguments
- fit
A fitted statistical model object.
- symbols
Optional named character vector mapping variable names to user-supplied LaTeX symbols, e.g.
c(body_mass = "W_i", temperature = "T_i").- units
Optional named character vector mapping variable names to units, e.g.
c(body_mass = "g", temperature = "C").- context
Optional short character description of the model, e.g.
"avian body-size location-scale model".- ...
Reserved for method-specific extra arguments.